@@ -72,10 +72,10 @@ ActivatableListWidget::ActivatableListWidget(RemoteActivatableList* activatables
 void ActivatableListWidget::init()
 {
     listAppeared();
-    connect(m_activatables, SIGNAL(activatableAdded(RemoteActivatable*, int)),
-            SLOT(activatableAdded(RemoteActivatable *, int)));
+    connect(m_activatables, SIGNAL(activatableAdded(RemoteActivatable*,int)),
+            SLOT(activatableAdded(RemoteActivatable*,int)));
     connect(m_activatables, SIGNAL(activatableRemoved(RemoteActivatable*)),
-            SLOT(activatableRemoved(RemoteActivatable *)));
+            SLOT(activatableRemoved(RemoteActivatable*)));
 
     connect(m_activatables, SIGNAL(appeared()), SLOT(listAppeared()));
     connect(m_activatables, SIGNAL(disappeared()), SLOT(listDisappeared()));
@@ -225,8 +225,8 @@ void ActivatableListWidget::createHiddenItem()
     //m_itemIndex[activatable] = ai;
     connect(m_hiddenItem, SIGNAL(disappearAnimationFinished()),
             this, SLOT(deleteItem()));
-    connect(m_hiddenItem, SIGNAL(connectToHiddenNetwork(const QString&)),
-            this, SLOT(connectToHiddenNetwork(const QString&)));
+    connect(m_hiddenItem, SIGNAL(connectToHiddenNetwork(QString)),
+            this, SLOT(connectToHiddenNetwork(QString)));
 }
 
 void ActivatableListWidget::listAppeared()
@@ -336,7 +336,7 @@ void ActivatableListWidget::deleteItem()
 {
     ActivatableItem* ai = dynamic_cast<ActivatableItem*>(sender());
     m_layout->removeItem(ai);
-    if (m_itemIndex.key(ai))
+    if (m_itemIndex.key(ai, 0))
         m_itemIndex.remove(m_itemIndex.key(ai));
     delete ai;
 }
