@@ -116,7 +116,7 @@ NetworkManagerApplet::NetworkManagerApplet(QObject * parent, const QVariantList
     kded.call(QLatin1String("loadModule"), QLatin1String("networkmanagement"));
 
     m_activatables = new RemoteActivatableList(this);
-    connect(m_activatables, SIGNAL(activatableAdded(RemoteActivatable*, int)), this, SLOT(activatableAdded(RemoteActivatable*)));
+    connect(m_activatables, SIGNAL(activatableAdded(RemoteActivatable*,int)), this, SLOT(activatableAdded(RemoteActivatable*)));
     connect(m_activatables, SIGNAL(activatableRemoved(RemoteActivatable*)), this, SLOT(activatableRemoved(RemoteActivatable*)));
     connect(m_activatables, SIGNAL(disappeared()), this, SLOT(activatablesDisappeared()));
 }
@@ -134,14 +134,6 @@ QString NetworkManagerApplet::svgElement(Solid::Control::NetworkInterfaceNm09 *i
         return QString(); // this means: use pixmap icons instead of svg icons.
     }
 
-    if (iface->type() == Solid::Control::NetworkInterfaceNm09::Ethernet) {
-        if (iface->connectionState() == Solid::Control::NetworkInterfaceNm09::Activated) {
-            return QString("network-wired-activated");
-        } else {
-            return QString("network-wired");
-        }
-    }
-
     if (iface->type() == Solid::Control::NetworkInterfaceNm09::Wifi) {
         // Now figure out which exact element we'll use
         QString strength = "00";
@@ -168,13 +160,17 @@ QString NetworkManagerApplet::svgElement(Solid::Control::NetworkInterfaceNm09 *i
             } else {
                     strength = '0';
             }
+
+            // The format in the SVG looks like this: wireless-signal-<strength>
+            return QString("network-wireless-%1").arg(strength);
         } else {
             return QString("dialog-error");
         }
-
-        // The format in the SVG looks like this: wireless-signal-<strength>
-        return QString("network-wireless-%1").arg(strength);
     } else if (iface->type() == Solid::Control::NetworkInterfaceNm09::Modem || iface->type() == Solid::Control::NetworkInterfaceNm09::Bluetooth) {
+        if (iface->connectionState() == Solid::Control::NetworkInterfaceNm09::Disconnected) {
+            return QString(); // this means: use KIcon("phone") instead of svg icon.
+        }
+
         Solid::Control::ModemNetworkInterfaceNm09 *giface = qobject_cast<Solid::Control::ModemNetworkInterfaceNm09*>(iface);
 
         if (giface) {
@@ -198,7 +194,12 @@ QString NetworkManagerApplet::svgElement(Solid::Control::NetworkInterfaceNm09 *i
                     strength = "100";
                 }
 
-                switch(modemNetworkIface->getAccessTechnology()) {
+                int accesstechnology = modemNetworkIface->getAccessTechnology();
+                if (iface->connectionState() != Solid::Control::NetworkInterfaceNm09::Activated) {
+                    accesstechnology = -1;
+                }
+
+                switch(accesstechnology) {
                     case Solid::Control::ModemInterface::UnknownTechnology:
                     case Solid::Control::ModemInterface::Gsm:
                     case Solid::Control::ModemInterface::GsmCompact:
@@ -216,13 +217,21 @@ QString NetworkManagerApplet::svgElement(Solid::Control::NetworkInterfaceNm09 *i
                     case Solid::Control::ModemInterface::Hsdpa:
                         return QString("network-mobile-%1-hsdpa").arg(strength);
                     case Solid::Control::ModemInterface::Hsupa:
-                        return QString("network-mobile-%1-hsdua").arg(strength);
+                        return QString("network-mobile-%1-hsupa").arg(strength);
                     case Solid::Control::ModemInterface::Hspa:
                         return QString("network-mobile-%1-hspa").arg(strength);
+                    default:
+                        return QString("network-mobile-%1-none").arg(strength);
                 }
             }
         }
         return QString(); // this means: use KIcon("phone") instead of svg icon.
+    } else if (iface->type() == Solid::Control::NetworkInterfaceNm09::Ethernet) {
+        if (iface->connectionState() == Solid::Control::NetworkInterfaceNm09::Activated) {
+            return QString("network-wired-activated");
+        } else {
+            return QString("network-wired");
+        }
     }
 
     return QString("dialog-error");
@@ -232,7 +241,7 @@ void NetworkManagerApplet::setupInterfaceSignals()
 {
     foreach (Solid::Control::NetworkInterfaceNm09* interface, m_interfaces) {
         // be aware of state changes
-        QObject::disconnect(interface, SIGNAL(connectionStateChanged(int, int, int)), this, SLOT(interfaceConnectionStateChanged()));
+        QObject::disconnect(interface, SIGNAL(connectionStateChanged(int,int,int)), this, SLOT(interfaceConnectionStateChanged()));
         QObject::disconnect(interface, SIGNAL(connectionStateChanged(int)), this, SLOT(interfaceConnectionStateChanged()));
         QObject::disconnect(interface, SIGNAL(linkUpChanged(bool)));
 
@@ -251,7 +260,7 @@ void NetworkManagerApplet::setupInterfaceSignals()
         } else if (interface->type() == Solid::Control::NetworkInterfaceNm09::Wifi) {
             Solid::Control::WirelessNetworkInterfaceNm09* wirelessiface =
                             static_cast<Solid::Control::WirelessNetworkInterfaceNm09*>(interface);
-            connect(wirelessiface, SIGNAL(activeAccessPointChanged(const QString&)), SLOT(setupAccessPointSignals(const QString&)));
+            connect(wirelessiface, SIGNAL(activeAccessPointChanged(QString)), SLOT(setupAccessPointSignals(QString)));
             QMetaObject::invokeMethod(wirelessiface, "activeAccessPointChanged",
                                       Q_ARG(QString, wirelessiface->activeAccessPoint()));
         } else if (interface->type() == Solid::Control::NetworkInterfaceNm09::Modem) {
@@ -292,10 +301,10 @@ void NetworkManagerApplet::init()
     }
 
     //kDebug();
-    QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceAdded(const QString&)),
-            this, SLOT(networkInterfaceAdded(const QString&)));
-    QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceRemoved(const QString&)),
-            this, SLOT(networkInterfaceRemoved(const QString&)));
+    QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceAdded(QString)),
+            this, SLOT(networkInterfaceAdded(QString)));
+    QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceRemoved(QString)),
+            this, SLOT(networkInterfaceRemoved(QString)));
 
     QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(statusChanged(Solid::Networking::Status)),
                      this, SLOT(managerStatusChanged(Solid::Networking::Status)));
@@ -320,8 +329,12 @@ void NetworkManagerApplet::init()
                                   Q_ARG(int, Solid::Control::NetworkInterfaceNm09::NoReason));
     }
 
-    connect(m_activatables, SIGNAL(appeared()), SLOT(finishInitialization()));
-    finishInitialization();
+    QDBusConnection dbus = QDBusConnection::sessionBus();
+    dbus.connect("org.kde.kded", "/org/kde/networkmanagement", "org.kde.networkmanagement", "ModuleReady", this, SLOT(finishInitialization()));
+
+    if (QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.networkmanagement")) {
+        QTimer::singleShot(0, this, SLOT(finishInitialization()));
+    }
 }
 
 void NetworkManagerApplet::finishInitialization()
@@ -337,7 +350,6 @@ QGraphicsWidget* NetworkManagerApplet::graphicsWidget()
 {
     if (!m_popup) {
         m_popup = new NMPopup(m_activatables, this);
-        connect(m_popup, SIGNAL(configNeedsSaving()), this, SIGNAL(configNeedsSaving()));
     }
     return m_popup;
 }
@@ -941,8 +953,8 @@ void NetworkManagerApplet::activatableAdded(RemoteActivatable *activatable)
 {
     RemoteInterfaceConnection *ic = qobject_cast<RemoteInterfaceConnection*>(activatable);
     if (activatable->activatableType() == Knm::Activatable::VpnInterfaceConnection) {
-        connect(ic, SIGNAL(activationStateChanged(Knm::InterfaceConnection::ActivationState, Knm::InterfaceConnection::ActivationState)),
-                this, SLOT(vpnActivationStateChanged(Knm::InterfaceConnection::ActivationState, Knm::InterfaceConnection::ActivationState)));
+        connect(ic, SIGNAL(activationStateChanged(Knm::InterfaceConnection::ActivationState,Knm::InterfaceConnection::ActivationState)),
+                this, SLOT(vpnActivationStateChanged(Knm::InterfaceConnection::ActivationState,Knm::InterfaceConnection::ActivationState)));
         QMetaObject::invokeMethod(ic, "activationStateChanged", Q_ARG(Knm::InterfaceConnection::ActivationState, ic->oldActivationState()), Q_ARG(Knm::InterfaceConnection::ActivationState, ic->activationState()));
     } else if (ic) {
         connect(ic, SIGNAL(hasDefaultRouteChanged(bool)), SLOT(updateActiveInterface(bool)));
@@ -980,7 +992,7 @@ void NetworkManagerApplet::updateActiveInterface(bool hasDefaultRoute)
     if (hasDefaultRoute) {
         // TODO: add support for VpnRemoteInterfaceConnection's, which have "any" as ic->deviceUni().
         setActiveInterface(Solid::Control::NetworkManagerNm09::findNetworkInterface(ic->deviceUni()));
-        connect(m_activeInterface, SIGNAL(destroyed(QObject *)), SLOT(_k_destroyed(QObject *)));
+        connect(m_activeInterface, SIGNAL(destroyed(QObject*)), SLOT(_k_destroyed(QObject*)));
         resetActiveSystrayInterface();
     }
 }
