@@ -44,6 +44,7 @@ public:
     QList<Knm::Connection*> connectionsToWrite;
     QList<Knm::Connection*> connectionsToRead;
     QMultiHash<QString,QPair<QString,SecretsProvider::GetSecretsFlags> > settingsToRead;
+    QList<QString> userAskRequestsInProgress;
 };
 
 
@@ -51,8 +52,8 @@ QString SecretStorage::s_walletFolderName = QLatin1String("Network Management");
 
 WId SecretStorage::s_walletWId = 0;
 
-SecretStorage::SecretStorage()
-    :SecretsProvider(), d_ptr(new SecretStoragePrivate())
+SecretStorage::SecretStorage(QObject * parent)
+    :SecretsProvider(parent), d_ptr(new SecretStoragePrivate())
 {
     Q_D(SecretStorage);
     KNetworkManagerServicePrefs::instance(Knm::NETWORKMANAGEMENT_RCFILE);
@@ -86,17 +87,19 @@ void SecretStorage::saveSecrets(Knm::Connection *con)
         }
     } else if (d->storageMode == Secure) {
         KWallet::Wallet * wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), walletWid(), KWallet::Wallet::Asynchronous );
-        if (wallet) {
-            connect(wallet, SIGNAL(walletOpened(bool)), this, SLOT(walletOpenedForWrite(bool)));
-            d->connectionsToWrite.append(con);
-        }
+        Q_ASSERT(wallet);
+
+        connect(wallet, SIGNAL(walletOpened(bool)), this, SLOT(walletOpenedForWrite(bool)));
+        d->connectionsToWrite.append(con);
     }
 }
 
 void SecretStorage::walletOpenedForWrite(bool success)
 {
     Q_D(SecretStorage);
-    KWallet::Wallet * wallet = static_cast<KWallet::Wallet*>(sender());
+    KWallet::Wallet * wallet = qobject_cast<KWallet::Wallet*>(sender());
+    Q_ASSERT(wallet);
+
     if (success) {
         if (wallet->isOpen()) {
             bool readyForWalletWrite = false;
@@ -131,7 +134,7 @@ void SecretStorage::walletOpenedForWrite(bool success)
             }
         }
     }
-    delete wallet;
+    wallet->deleteLater();
 }
 
 void SecretStorage::walletOpenedForRead(bool success)
@@ -140,6 +143,8 @@ void SecretStorage::walletOpenedForRead(bool success)
     kDebug();
     bool retrievalSuccessful = true;
     KWallet::Wallet * wallet = static_cast<KWallet::Wallet*>(sender());
+    Q_ASSERT(wallet);
+
     if (success) {
         if (wallet->isOpen() && wallet->hasFolder(s_walletFolderName) && wallet->setFolder(s_walletFolderName)) {
             while (!d->connectionsToRead.isEmpty()) {
@@ -152,6 +157,10 @@ void SecretStorage::walletOpenedForRead(bool success)
                     QPair<QString,GetSecretsFlags> pair = i.value();
                     bool settingsFound = false;
                     foreach (Knm::Setting * setting, con->settings()) {
+                        if (!setting) {
+                            kWarning() << "Setting for " << con->uuid() << " is null. That should not happen.";
+                            continue;
+                        }
                         if (setting->name() == pair.first) {
                             settingsFound = true;
                             QMap<QString,QString> map;
@@ -177,7 +186,7 @@ void SecretStorage::walletOpenedForRead(bool success)
             retrievalSuccessful = false;
         }
     }
-    delete wallet;
+    wallet->deleteLater();
 
     if (!retrievalSuccessful || !success) {
          while (!d->connectionsToRead.isEmpty()) {
@@ -208,16 +217,15 @@ void SecretStorage::deleteSecrets(Knm::Connection *con)
         QFile::remove(ptr->name());
     } else if (d->storageMode == Secure) {
         KWallet::Wallet * wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), walletWid(), KWallet::Wallet::Synchronous );
-        if( wallet && wallet->isOpen() && wallet->hasFolder( s_walletFolderName ) && wallet->setFolder( s_walletFolderName )) {
+        Q_ASSERT(wallet);
+
+        if( wallet->isOpen() && wallet->hasFolder( s_walletFolderName ) && wallet->setFolder( s_walletFolderName )) {
             foreach (const QString & k, wallet->entryList()) {
                 if (k.startsWith(con->uuid() + ';'))
                     wallet->removeEntry(k);
             }
         }
-        
-        if (wallet) {
-            delete wallet;
-        }
+        wallet->deleteLater();
     }
 }
 
@@ -246,7 +254,7 @@ void SecretStorage::loadSecrets(Knm::Connection *con, const QString &name, GetSe
         Knm::Setting *setting = con->setting(Knm::Setting::typeFromString(name));
         setting->secretsFromMap(map);
         QStringList needSecretsList = setting->needSecrets();
-        if (!needSecretsList.isEmpty() && (flags & AllowInteraction || flags & RequestNew)) {
+        if ((flags & RequestNew) || (!needSecretsList.isEmpty() && (flags & AllowInteraction))) {
             askUser(con, name, needSecretsList);
         } else {
             emit connectionRead(con, name, false, false);
@@ -255,19 +263,41 @@ void SecretStorage::loadSecrets(Knm::Connection *con, const QString &name, GetSe
         kDebug() << "opening wallet...";
         KWallet::Wallet * wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(),
                 walletWid(),KWallet::Wallet::Asynchronous);
-        if (wallet) {
-            connect(wallet, SIGNAL(walletOpened(bool)), this, SLOT(walletOpenedForRead(bool)));
-            d->connectionsToRead.append(con);
-            QPair<QString,GetSecretsFlags> pair(name, flags);
-            d->settingsToRead.insert(uuid, pair);
-        } else {
-            emit connectionRead(con, name, true, false);
+        Q_ASSERT(wallet);
+
+        // remove stale request to prevent crashes.
+        // https://bugs.kde.org/show_bug.cgi?id=283105
+        QMutableListIterator<Knm::Connection *> conIter(d->connectionsToRead);
+        while (conIter.hasNext()) {
+            Knm::Connection * c = conIter.next();
+            if (c->uuid() == con->uuid()) {
+                QMutableHashIterator<QString, QPair<QString,GetSecretsFlags> > i(d->settingsToRead);
+                while (i.hasNext()) {
+                    if (i.next().key() != c->uuid())
+                        continue;
+                    QPair<QString,GetSecretsFlags> pair = i.value();
+                    i.remove();
+                    kDebug() << "Removing stale request" << c->uuid() << pair.first;
+                }
+                delete c;
+                conIter.remove();
+            }
         }
+
+        connect(wallet, SIGNAL(walletOpened(bool)), this, SLOT(walletOpenedForRead(bool)));
+        d->connectionsToRead.append(con);
+        QPair<QString,GetSecretsFlags> pair(name, flags);
+        d->settingsToRead.insert(uuid, pair);
     }
 }
 
 void SecretStorage::askUser(Knm::Connection *con, const QString & name, const QStringList &secrets)
 {
+    Q_D(SecretStorage);
+    if (d->userAskRequestsInProgress.contains(con->uuid().toString())) {
+        return;
+    }
+    d->userAskRequestsInProgress.append(con->uuid().toString());
     ConnectionSecretsJob *job = new ConnectionSecretsJob(con, name, secrets);
     connect(job, SIGNAL(finished(KJob*)), this, SLOT(gotSecrets(KJob*)));
     job->start();
@@ -291,12 +321,18 @@ KSharedConfig::Ptr SecretStorage::secretsFileForUuid(const QString & uuid)
 
 void SecretStorage::gotSecrets(KJob *job)
 {
+    Q_D(SecretStorage);
     ConnectionSecretsJob * csj = static_cast<ConnectionSecretsJob*>(job);
     bool failed = true;
     if (csj->error() == ConnectionSecretsJob::EnumError::NoError) {
         failed = false;
     }
-    emit connectionRead(csj->connection(), csj->settingName(), failed, true);
+    Knm::Connection * con = csj->connection();
+
+    if (con) {
+        d->userAskRequestsInProgress.removeAll(con->uuid().toString());
+    }
+    emit connectionRead(con, csj->settingName(), failed, true);
 }
 
 void SecretStorage::switchStorage(SecretStorageMode oldMode, SecretStorageMode newMode)
@@ -307,8 +343,8 @@ void SecretStorage::switchStorage(SecretStorageMode oldMode, SecretStorageMode n
 
     KWallet::Wallet * wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(),
         walletWid(),KWallet::Wallet::Synchronous);
-    if (!wallet)
-        return;
+    Q_ASSERT(wallet);
+
     if( !wallet->hasFolder( s_walletFolderName ) )
         wallet->createFolder( s_walletFolderName );
     wallet->setFolder( s_walletFolderName );
@@ -337,5 +373,5 @@ void SecretStorage::switchStorage(SecretStorageMode oldMode, SecretStorageMode n
             wallet->removeEntry(key);
         }
     }
-    delete wallet;
+    wallet->deleteLater();
 }
