@@ -21,6 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "manageconnectionwidget.h"
+#include "treewidgetitem.h"
 
 #include <unistd.h>
 
@@ -66,11 +67,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <tooltips.h>
 
-#define ConnectionIdRole Qt::UserRole + 1
-#define ConnectionTypeRole Qt::UserRole + 2
-#define ConnectionLastUsedRole Qt::UserRole + 3
-#define ConnectionStateRole Qt::UserRole + 4
-
 #define ConnectionNameColumn 0
 #define ConnectionLastUsedColumn 1
 #define ConnectionStateColumn 2
@@ -107,8 +103,8 @@ ManageConnectionWidget::ManageConnectionWidget(QWidget *parent, const QVariantLi
     mConnections = new ConnectionList(this);
     mSystemSettings = new NMDBusSettingsConnectionProvider(mConnections, this);
 
-    connect(mSystemSettings, SIGNAL(getConnectionSecretsCompleted(bool, const QString &, const QString &)), this, SLOT(editGotSecrets(bool, const QString&, const QString &)) );
-    connect(mSystemSettings, SIGNAL(addConnectionCompleted(bool, const QString &)), this, SLOT(addGotConnection(bool, const QString&)) );
+    connect(mSystemSettings, SIGNAL(getConnectionSecretsCompleted(bool,QString,QString)), this, SLOT(editGotSecrets(bool,QString,QString)) );
+    connect(mSystemSettings, SIGNAL(addConnectionCompleted(bool,QString)), this, SLOT(addGotConnection(bool,QString)) );
 
     connect(mSystemSettings, SIGNAL(connectionsChanged()), this, SLOT(restoreConnections()));
 
@@ -137,9 +133,9 @@ ManageConnectionWidget::ManageConnectionWidget(QWidget *parent, const QVariantLi
     connectButtonSet(mConnEditUi.buttonSetCellular, mConnEditUi.listCellular);
     connectButtonSet(mConnEditUi.buttonSetVpn, mConnEditUi.listVpn);
     connectButtonSet(mConnEditUi.buttonSetPppoe, mConnEditUi.listPppoe);
-    connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceAdded(const QString&)),
+    connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceAdded(QString)),
             SLOT(updateTabStates()));
-    connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceRemoved(const QString&)),
+    connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceRemoved(QString)),
             SLOT(updateTabStates()));
     connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(activeConnectionsChanged()),
             SLOT(activeConnectionsChanged()));
@@ -284,35 +280,34 @@ void ManageConnectionWidget::restoreConnections()
         itemContents << QString();
 
         kDebug() << type << name << lastUsed;
-        QTreeWidgetItem * item = 0;
+        TreeWidgetItem * item = 0;
         if (type == Knm::Connection::typeAsString(Knm::Connection::Wired)) {
-            item = new QTreeWidgetItem(mConnEditUi.listWired, itemContents);
+            item = new TreeWidgetItem(mConnEditUi.listWired, itemContents);
             wiredItems.append(item);
         } else if (type == Knm::Connection::typeAsString(Knm::Connection::Wireless)) {
-            item = new QTreeWidgetItem(mConnEditUi.listWireless, itemContents);
+            item = new TreeWidgetItem(mConnEditUi.listWireless, itemContents);
             wirelessItems.append(item);
         } else if (type == Knm::Connection::typeAsString(Knm::Connection::Gsm)) {
-            item = new QTreeWidgetItem(mConnEditUi.listCellular, itemContents);
+            item = new TreeWidgetItem(mConnEditUi.listCellular, itemContents);
             cellularItems.append(item);
         } else if (type == Knm::Connection::typeAsString(Knm::Connection::Cdma)) {
-            item = new QTreeWidgetItem(mConnEditUi.listCellular, itemContents);
+            item = new TreeWidgetItem(mConnEditUi.listCellular, itemContents);
             cellularItems.append(item);
         } else if (type == Knm::Connection::typeAsString(Knm::Connection::Bluetooth)) {
-            item = new QTreeWidgetItem(mConnEditUi.listCellular, itemContents);
+            item = new TreeWidgetItem(mConnEditUi.listCellular, itemContents);
             cellularItems.append(item);
         } else if (type == Knm::Connection::typeAsString(Knm::Connection::Vpn)) {
-            item = new QTreeWidgetItem(mConnEditUi.listVpn, itemContents);
+            item = new TreeWidgetItem(mConnEditUi.listVpn, itemContents);
             vpnItems.append(item);
         } else if (type == Knm::Connection::typeAsString(Knm::Connection::Pppoe)) {
-            item = new QTreeWidgetItem(mConnEditUi.listPppoe, itemContents);
+            item = new TreeWidgetItem(mConnEditUi.listPppoe, itemContents);
             pppoeItems.append(item);
         }
 
         if (item) {
             mUuidItemHash.insert(connectionId, item);
-            item->setData(0, ConnectionIdRole, connectionId);
-            item->setData(0, ConnectionTypeRole, Knm::Connection::typeFromString(type));
-            item->setData(0, ConnectionLastUsedRole, lastUsed);
+            item->setData(0, TreeWidgetItem::ConnectionIdRole, connectionId);
+            item->setData(0, TreeWidgetItem::ConnectionLastUsedRole, lastUsed);
         }
     }
     mConnEditUi.listWired->insertTopLevelItems(0, wiredItems);
@@ -468,7 +463,7 @@ void ManageConnectionWidget::exportClicked()
 {
     QTreeWidgetItem * item = selectedItem();
     Knm::Connection * con = 0;
-    QString connectionId = item->data(0, ConnectionIdRole).toString();
+    QString connectionId = item->data(0, TreeWidgetItem::ConnectionIdRole).toString();
     if (connectionId.isEmpty()) {
         kDebug() << "selected item had no connectionId!";
         return;
@@ -512,8 +507,7 @@ void ManageConnectionWidget::editClicked()
     if (item) {
         Knm::Connection *con = 0;
 
-        QString connectionId = item->data(0, ConnectionIdRole).toString();
-        //Knm::Connection::Type type = (Knm::Connection::Type)item->data(0, ConnectionTypeRole).toUInt();
+        QString connectionId = item->data(0, TreeWidgetItem::ConnectionIdRole).toString();
         if (connectionId.isEmpty()) {
             kDebug() << "selected item had no connectionId!";
             return;
@@ -590,7 +584,7 @@ void ManageConnectionWidget::deleteClicked()
         kDebug() << "delete clicked, but no selection!";
         return;
     }
-    QString connectionId = item->data(0, ConnectionIdRole).toString();
+    QString connectionId = item->data(0, TreeWidgetItem::ConnectionIdRole).toString();
     if (connectionId.isEmpty()) {
         kDebug() << "item to be deleted had no connectionId!";
         return;
@@ -777,7 +771,7 @@ void ManageConnectionWidget::updateLastUsed(QTreeWidget * list)
 {
     QTreeWidgetItemIterator it(list);
     while (*it) {
-        QDateTime lastUsed = (*it)->data(0, ConnectionLastUsedRole).toDateTime();
+        QDateTime lastUsed = (*it)->data(0, TreeWidgetItem::ConnectionLastUsedRole).toDateTime();
         (*it)->setText(ConnectionLastUsedColumn, formatDateRelative(lastUsed));
         ++it;
     }
