@@ -1,6 +1,6 @@
 
 /*
-Copyright 2010-2011 Lamarque Souza <lamarque@gmail.com>
+Copyright 2010-2012 Lamarque Souza <lamarque@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -32,6 +32,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "mobileconnectionwizard.h"
 
+#define NUMBER_OF_STATIC_ENTRIES 3
+
 MobileConnectionWizard::MobileConnectionWizard(Knm::Connection::Type connectionType, QWidget * parent): QWizard(parent)
 {
     if (connectionType == Knm::Connection::Unknown) {
@@ -98,7 +100,7 @@ void MobileConnectionWizard::initializePage(int id)
                     }
                     /* TODO: test for Lte */
                 } else {
-                    mType = Knm::Connection::Gsm;
+                    mType = static_cast<Knm::Connection::Type>(mDeviceComboBox->itemData(mDeviceComboBox->currentIndex()).toUInt());
                 }
             }
 
@@ -139,7 +141,7 @@ void MobileConnectionWizard::initializePage(int id)
             break;
 
         case 3: // Plans Page
-            disconnect(mPlanComboBox, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(slotEnablePlanEditBox(const QString &)));
+            disconnect(mPlanComboBox, SIGNAL(currentIndexChanged(QString)), this, SLOT(slotEnablePlanEditBox(QString)));
             mPlanComboBox->clear();
             if (type() != Knm::Connection::Gsm) {
                 goto OUT_3;
@@ -165,7 +167,7 @@ void MobileConnectionWizard::initializePage(int id)
                 mPlanComboBox->addItem(i18nc("Mobile Connection Wizard", "My plan is not listed..."));
             }
 OUT_3:
-            connect(mPlanComboBox, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(slotEnablePlanEditBox(const QString &)));
+            connect(mPlanComboBox, SIGNAL(currentIndexChanged(QString)), this, SLOT(slotEnablePlanEditBox(QString)));
         break;
 
         case 4: // Confirm Page
@@ -264,15 +266,18 @@ QWizardPage * MobileConnectionWizard::createIntroPage()
         layout->addWidget(label);
     
         mDeviceComboBox = new QComboBox();
-        mDeviceComboBox->addItem(i18nc("Mobile Connection Wizard", "Any device"));
-        mDeviceComboBox->insertSeparator(1);
+        mDeviceComboBox->addItem(i18nc("Mobile Connection Wizard", "Any GSM device"));
+        mDeviceComboBox->setItemData(0, Knm::Connection::Gsm);
+        mDeviceComboBox->addItem(i18nc("Mobile Connection Wizard", "Any CDMA device"));
+        mDeviceComboBox->setItemData(1, Knm::Connection::Cdma);
+        mDeviceComboBox->insertSeparator(NUMBER_OF_STATIC_ENTRIES-1);
         label->setBuddy(mDeviceComboBox);
         layout->addWidget(mDeviceComboBox);
     
-        QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceAdded(const QString)),
-                         this, SLOT(introDeviceAdded(const QString)));
-        QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceRemoved(const QString)),
-                         this, SLOT(introDeviceRemoved(const QString)));
+        QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceAdded(QString)),
+                         this, SLOT(introDeviceAdded(QString)));
+        QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(networkInterfaceRemoved(QString)),
+                         this, SLOT(introDeviceRemoved(QString)));
         QObject::connect(Solid::Control::NetworkManagerNm09::notifier(), SIGNAL(statusChanged(Solid::Networking::Status)),
                          this, SLOT(introStatusChanged(Solid::Networking::Status)));
     
@@ -328,12 +333,10 @@ void MobileConnectionWizard::introAddDevice(Solid::Control::NetworkInterfaceNm09
 
     mDeviceComboBox->addItem(desc, device->uni());
 
-    if (mDeviceComboBox->count() == 2) {
+    if (mDeviceComboBox->count() == NUMBER_OF_STATIC_ENTRIES) {
         mDeviceComboBox->setCurrentIndex(0);
-        mDeviceComboBox->setEnabled(false);
     } else {
-        mDeviceComboBox->setCurrentIndex(2);
-        mDeviceComboBox->setEnabled(true);
+        mDeviceComboBox->setCurrentIndex(NUMBER_OF_STATIC_ENTRIES);
     }
 }
 
@@ -348,15 +351,13 @@ void MobileConnectionWizard::introDeviceRemoved(const QString uni)
 
     mDeviceComboBox->removeItem(index);
 
-    if (mDeviceComboBox->count() == 2) {
+    if (mDeviceComboBox->count() == NUMBER_OF_STATIC_ENTRIES) {
         mDeviceComboBox->setCurrentIndex(0);
-        mDeviceComboBox->setEnabled(false);
         if (currentId() > 0) {
             close();
         }
     } else {
-        mDeviceComboBox->setCurrentIndex(2);
-        mDeviceComboBox->setEnabled(true);
+        mDeviceComboBox->setCurrentIndex(NUMBER_OF_STATIC_ENTRIES);
     }
 }
 
@@ -381,22 +382,22 @@ void MobileConnectionWizard::introAddInitialDevices()
         introAddDevice(n);
     }
 
-    if (mDeviceComboBox->count() == 2) {
+    if (mDeviceComboBox->count() == NUMBER_OF_STATIC_ENTRIES) {
         mDeviceComboBox->setCurrentIndex(0);
-        mDeviceComboBox->setEnabled(false);
     } else {
-        mDeviceComboBox->setCurrentIndex(2);
-        mDeviceComboBox->setEnabled(true);
+        mDeviceComboBox->setCurrentIndex(NUMBER_OF_STATIC_ENTRIES);
     }
 }
 
 void MobileConnectionWizard::introRemoveAllDevices()
 {
     mDeviceComboBox->clear();
-    mDeviceComboBox->addItem(i18nc("Mobile Connection Wizard", "Any device"));
-    mDeviceComboBox->insertSeparator(1);
+    mDeviceComboBox->addItem(i18nc("Mobile Connection Wizard", "Any GSM device"));
+    mDeviceComboBox->setItemData(0, Knm::Connection::Gsm);
+    mDeviceComboBox->addItem(i18nc("Mobile Connection Wizard", "Any CDMA device"));
+    mDeviceComboBox->setItemData(1, Knm::Connection::Cdma);
+    mDeviceComboBox->insertSeparator(NUMBER_OF_STATIC_ENTRIES-1);
     mDeviceComboBox->setCurrentIndex(0);
-    mDeviceComboBox->setEnabled(false);
 }
 
 /**********************************************************/
@@ -438,7 +439,7 @@ QWizardPage * MobileConnectionWizard::createProvidersPage()
 
     mProvidersList = new QListWidget();
     connect(mProvidersList, SIGNAL(itemSelectionChanged()), this, SLOT(slotCheckProviderList()));
-    connect(mProvidersList, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(slotCheckProviderList()));
+    connect(mProvidersList, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(slotCheckProviderList()));
     layout->addWidget(mProvidersList);
 
     radioManualProvider = new QRadioButton(i18nc("Mobile Connection Wizard", "I can't find my provider and I wish to enter it &manually:"));
@@ -447,7 +448,7 @@ QWizardPage * MobileConnectionWizard::createProvidersPage()
 
     lineEditProvider = new QLineEdit();
     layout->addWidget(lineEditProvider);
-    connect(lineEditProvider, SIGNAL(textEdited(const QString)), this, SLOT(slotCheckProviderEdit()));
+    connect(lineEditProvider, SIGNAL(textEdited(QString)), this, SLOT(slotCheckProviderEdit()));
 
     page->setLayout(layout);
 
